@@ -21,7 +21,7 @@ class LimitValue(CloudFormationLintRule):
 
         matches = []
 
-        value_limit = LIMITS['parameters']['value']
+        value_limit = LIMITS['Parameters']['value']
 
         # There are no real "Values" in the template, check the "meta" information
         # (Default, AllowedValue and MaxLength) against the limit
@@ -60,7 +60,6 @@ class LimitValue(CloudFormationLintRule):
                     if len(allowed_value) > value_limit:
                         path = ['Parameters', paramname, 'AllowedValues']
                         message = 'The length of parameter allowed value ({0}) exceeds the limit ({1})'
-                        matches.append(RuleMatch(path, message.format(
-                            len(allowed_value), value_limit)))
+                        matches.append(RuleMatch(path, message.format(len(allowed_value), value_limit)))
 
         return matches
