@@ -3,8 +3,7 @@ Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 SPDX-License-Identifier: MIT-0
 """
 from cfnlint.rules import CloudFormationLintRule
-from cfnlint.rules import RuleMatch
-from cfnlint.helpers import LIMITS
+from cfnlint.rules.limits import name_limit
 
 
 class LimitName(CloudFormationLintRule):
@@ -17,15 +16,4 @@ class LimitName(CloudFormationLintRule):
 
     def match(self, cfn):
         """Check CloudFormation Resources"""
-
-        matches = []
-
-        resources = cfn.template.get('Resources', {})
-
-        for resource_name in resources:
-            path = ['Resources', resource_name]
-            if len(resource_name) > LIMITS['resources']['name']:
-                message = 'The length of resource name ({0}) exceeds the limit ({1})'
-                matches.append(RuleMatch(path, message.format(len(resource_name), LIMITS['resources']['name'])))
-
-        return matches
+        return name_limit(cfn, 'Resources')
