@@ -18,12 +18,8 @@ class LimitDescription(CloudFormationLintRule):
     def match(self, cfn):
         """Basic Matching"""
         matches = []
-
         description = cfn.template.get('Description', '')
-
         if len(description) > LIMITS['template']['description']:
-            path = ['Template', 'Description']
             message = 'The template description ({0} bytes) exceeds the limit ({1} bytes)'
-            matches.append(RuleMatch(path, message.format(len(description), LIMITS['template']['description'])))
-
+            matches.append(RuleMatch(['Template', 'Description'], message.format(len(description), LIMITS['template']['description'])))
         return matches
