@@ -85,6 +85,8 @@ class Transform(object):
                     Transform._update_to_s3_uri('DefinitionUri', resource_dict)
                 else:
                     resource_dict['DefinitionBody'] = ''
+            if resource_type == 'AWS::Serverless::StateMachine':
+                Transform._update_to_s3_uri('DefinitionUri', resource_dict)
 
     def transform_template(self):
         """
